#!@@SHELL@@
#
# opkhelper
# src/oh-installdocs
# Install package documentation into a binary package staging area.
#
# Copyright (C) 2012 Patrick "P. J." McDermott
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

. @@LIBDIR@@/opkhelper/messages

print_usage()
{
	printf 'Usage: %s providing_pkg\n' "${1}"
}

if [ ${#} -ne 1 ]; then
	print_usage ${0} >&2
	exit 1
fi

# Iterate through packages that have been installed.
for pkgdir in *.data/; do
	pkg=${pkgdir%'.data/'}
	docdir=${pkgdir}usr/share/doc
	mkdir -p ${docdir}
	if [ ${pkg} = ${1} ]; then
		# Make the providing package provide the documentation files.
		oh_info 'Installing package documentation into package "%s"...' "${pkg}"
		mkdir -p ${docdir}/${pkg}
		cp ../copyright ${docdir}/${pkg}/copyright || \
			oh_error 'Cannot copy "copyright"'
		cp ../changelog ${docdir}/${pkg}/changelog.dist || \
			oh_error 'Cannot copy "changelog"'
		if [ -f ../README ]; then
			cp ../README ${docdir}/${pkg}/README.dist || \
				oh_error 'Cannot copy package "README"'
		fi
	else
		# Make dependent packages link to the providing package's documentation
		# directory.
		oh_info 'Making link to documentation in package "%s"...' "${pkg}"
		ln -s /usr/share/doc/${1} ${docdir}/${pkg} || \
			oh_error 'Cannot make link to documentation files'
	fi
done
